@@ -1,23 +1,18 @@
-from taskw_gcal_sync import GCalSide
-from taskw_gcal_sync import GenericSide
-from taskw_gcal_sync import TaskWarriorSide
-from taskw_gcal_sync.PrefsManager import PrefsManager
-from taskw_gcal_sync.clogger import setup_logging
-
-from bidict import bidict
-from typing import Any, Tuple, List, Dict, Union, Set
 import atexit
-import logging
 import os
-from functools import partial
 import pickle
 import sys
-
-from uuid import UUID
+import traceback
 from datetime import timedelta
+from functools import partial
+from typing import Any, Dict, List, Set, Tuple, Union
+from uuid import UUID
 
-logger = logging.getLogger(__name__)
-setup_logging(__name__)
+from bidict import bidict
+from loguru import logger
+
+from taskw_gcal_sync import GCalSide, GenericSide, TaskWarriorSide
+from taskw_gcal_sync.PrefsManager import PrefsManager
 
 pickle_dump = partial(pickle.dump, protocol=0)
 
@@ -135,8 +130,7 @@ class TWGCalAggregator:
         os.makedirs(self.config["gcal_serdes_dir"], exist_ok=True)
 
     def cleanup(self):
-        """Method to be called automatically on instance destruction.
-        """
+        """Method to be called automatically on instance destruction."""
 
         if not self.cleaned_up:
             if self.config["report_stats"]:
@@ -194,6 +188,7 @@ class TWGCalAggregator:
                             _id, item_converted, sys.exc_info()
                         )
                     )
+                    logger.error(traceback.format_exc())
                     other_stats.error()
                 else:
                     #  Add registry entry
@@ -219,10 +214,6 @@ class TWGCalAggregator:
                 prev_item = pickle.load(open(os.path.join(serdes_dir, _id), "rb"))
 
                 # Unchanged item
-
-                # if self.item_has_update(prev_item, item, item_type):
-                #     import ipdb; ipdb.set_trace()
-
                 if not self.item_has_update(prev_item, item, item_type):
                     logger.info("[{}] Unchanged item, id: {}...".format(item_type, _id))
                     continue
@@ -259,6 +250,7 @@ class TWGCalAggregator:
                         'Updating item "{}" failed.\nItem contents:'
                         "\n\n{}\n\nException: {}\n".format(_id, other_item_new, sys.exc_info())
                     )
+                    logger.error(traceback.format_exc())
                     other_stats.error()
                 else:
                     # Update cached version
@@ -304,7 +296,7 @@ class TWGCalAggregator:
         return type_key, other_type_key
 
     def synchronise_deleted_items(self, item_type: str) -> None:
-        """ Synchronise a task deleted at the side of `item_type`.
+        """Synchronise a task deleted at the side of `item_type`.
 
         Deleted tasks are detected from cached entries in the items mapping that
         don't exist anymore in the side of `item_type`.
@@ -366,12 +358,14 @@ class TWGCalAggregator:
                         "github.com/bergercookie/taskw_gcal_sync", sys.exc_info()
                     )
                 )
+                logger.error(traceback.format_exc())
                 other_stats.error()
             except KeyError:
                 logger.error(
                     "Item to delete [{}] is not present."
                     "\n\n{}\n\nException: {}\n".format(_id, other_item, sys.exc_info())
                 )
+                logger.error(traceback.format_exc())
                 other_stats.error()
             except KeyboardInterrupt:
                 raise
@@ -380,6 +374,7 @@ class TWGCalAggregator:
                     'Deleting item "{}" failed.\nItem contents:'
                     "\n\n{}\n\nException: {}\n".format(_id, other_item, sys.exc_info())
                 )
+                logger.error(traceback.format_exc())
                 other_stats.error()
 
         # Remove ids (out of loop)
@@ -394,6 +389,7 @@ class TWGCalAggregator:
             prev_item, new_item, ignore_keys=["urgency", "modified", "updated"]
         )
 
+    # currently unused.
     @staticmethod
     def compare_tw_gcal_items(
         tw_item: dict, gcal_item: dict
@@ -487,7 +483,7 @@ class TWGCalAggregator:
 
         # Status
         if status not in ["pending", "completed", "deleted", "waiting", "recurring"]:
-            logger.warn(
+            logger.warning(
                 "Invalid status %s in GCal->TW conversion of item. Skipping status:" % status
             )
         else:
@@ -518,9 +514,7 @@ class TWGCalAggregator:
 
     @staticmethod
     def _parse_gcal_item_desc(gcal_item: dict) -> Tuple[List[str], str, Union[UUID, None]]:
-        """Parse and return the necessary TW fields off a Google Calendar Item.
-
-        """
+        """Parse and return the necessary TW fields off a Google Calendar Item."""
         annotations: List[str] = []
         status = "pending"
         uuid = None
@@ -559,5 +553,6 @@ class TWGCalAggregator:
                             "Invalid UUID %s provided during GCal "
                             "-> TW conversion, Using None..." % err
                         )
+                        logger.error(traceback.format_exc())
 
         return annotations, status, uuid
